@@ -36,7 +36,10 @@ class GenerateGraphWidget : public QDialog
         CircleGraph,
         RandomEdgeGraph,
         ErdosRenyiRandomGraph,
-        RandomTree
+        RandomTree,
+        PathGraph,
+        CompleteGraph,
+        CompleteBipartiteGraph
     };
 
 public:
@@ -140,6 +143,29 @@ private:
      */
     void generateRandomTreeGraph(int nodes);
 
+    /**
+     * Generate a path graph with specified number of nodes.
+     *
+     * \param pathSize is the number of nodes of the generated graph
+     */
+    void generatePathGraph(int pathSize);
+
+    /**
+     * Generate a complete graph with specified number of nodes.
+     *
+     * \param nodes is the number of nodes of the generated graph
+     */
+    void generateCompleteGraph(int nodes);
+
+
+    /**
+     * Generate a complete bipartite graph with specified number of nodes.
+     *
+     * \param nodes_left is the number of nodes in the left set of the bipartite graph.
+     * \param nodes_right is the number of nodes in the right set of the bipartite graph.
+     */
+    void generateCompleteBipartiteGraph(int nodes_left, int nodes_right);
+
     GraphDocumentPtr m_document;
     int m_seed;
     NodeTypePtr m_nodeType;
